@@ -17,6 +17,7 @@
 static int
 post_fork_child()
 {
+	rs_pid = getpid();
 	if (!rs_opt_hb)
 		return 0; /* nothing to do if there is no hb */
 	if (0 > rs_init_heartbeat()) {
@@ -44,17 +45,23 @@ rs_fork()
 	/* avoid races with shm garbage collector in hb alarm handler */
 	rs_stop_heartbeat(&set);
 
-	/* share rocks that are not already shared */
 	for (i = 0; i < RS_MAXFD; i++) {
 		rs_t rs;
 		rs = rs_lookup(i);
-		if (rs && rs->state != RS_NOTCONNECTED
-		    && !rs_rock_is_shared(rs)) {
-			rv = rs_shm_create(rs);
-			if (0 > rv) {
-				rs_log("fork cannot create shared rock");
-				goto out;
+		if (!rs)
+			continue;
+
+		/* share shareworthy rocks that are not already shared */
+		if (rs->state != RS_NOTCONNECTED && rs->state != RS_EDP) {
+			if (!rs_rock_is_shared(rs)) {
+				if (0 > rs_shm_create(rs)) {
+					rs_log("fork cannot share rock");
+					goto out;
+				}
 			}
+			rs_shm_lock(rs->shm);
+			rs->shm->refcnt++;
+			rs_shm_unlock(rs->shm);
 		}
 	}
 
