@@ -24,11 +24,11 @@ rs_setsockopt(int s, int level, int optname,
 		return 0;
 	}
 	if (level == SOL_SOCKET && optname == SO_SNDBUF) {
-		rs_log("Ignoring app SO_SNDBUF");
+		rs_log("Ignoring app SO_SNDBUF (%d)", *(unsigned long*)optval);
 		return 0;
 	}
 	if (level == SOL_SOCKET && optname == SO_RCVBUF) {
-		rs_log("Ignoring app SO_RCVBUF");
+		rs_log("Ignoring app SO_RCVBUF (%d)", *(unsigned long*)optval);
 		return 0;
 	}
 	if (level == SOL_SOCKET && optname == SO_LINGER) {
@@ -44,7 +44,8 @@ int
 rs_fcntl(int fd, int cmd, long arg)
 {
 	if (cmd == F_SETFL && (arg & O_NONBLOCK)) {
-		rs_log("Ignoring app NONBLOCK");
+		rs_log("Not ignoring app NONBLOCK");
+		fcntl(fd, cmd, O_NONBLOCK);
 		return 0;
 	} else if (cmd == F_DUPFD) {
 		rs_log("SHIT! Ignoring app F_DUPFD");
